Learn R Programming

CohortConstructor (version 0.6.1)

mockCohortConstructor: Function to create a mock cdm reference for CohortConstructor

Description

mockCohortConstructor() creates an example dataset that can be used for demonstrating and testing the package

Usage

mockCohortConstructor(source = "local")

Value

cdm object

Arguments

source

Source for the mock cdm, it can either be 'local' or 'duckdb'.

Examples

Run this code
# \donttest{
library(CohortConstructor)
cdm <- mockCohortConstructor()

cdm
# }

Run the code above in your browser using DataLab