powered by
mockCohortConstructor() creates an example dataset that can be used for demonstrating and testing the package
mockCohortConstructor()
mockCohortConstructor(source = "local")
cdm object
Source for the mock cdm, it can either be 'local' or 'duckdb'.
# \donttest{ library(CohortConstructor) cdm <- mockCohortConstructor() cdm # }
Run the code above in your browser using DataLab