powered by
Utility function to change the name of a cohort.
renameCohort(cohort, newCohortName, cohortId = NULL)
A cohort_table object.
A cohort table in a cdm reference.
Character vector with same
Vector identifying which cohorts to modify (cohort_definition_id or cohort_name). If NULL, all cohorts will be used; otherwise, only the specified cohorts will be modified, and the rest will remain unchanged.
# \donttest{ library(CohortConstructor) cdm <- mockCohortConstructor() settings(cdm$cohort1) cdm$cohort1 <- cdm$cohort1 |> renameCohort(newCohortName = "new_name") settings(cdm$cohort1) # }
Run the code above in your browser using DataLab